==> cms-db_v0.8.1.tar.gz: admin/xmlurls.inc.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

if (!defined('cms-db')) {
	include('friendlyerror.firewall.inc.php');
	die();
}

function getServerName() {
	$server_name = 'http';
	if ($_SERVER['HTTPS'] == 'on') {
		$server_name .= 's';
	}
	$server_name .= '://';
	if ($_SERVER['SERVER_PORT'] != '80') {
		$server_name .= $_SERVER['SERVER_NAME'].':'.$_SERVER['SERVER_PORT'];
	} else {
		$server_name .= $_SERVER['SERVER_NAME'];
	}
	return $server_name;
}
function getRequestUri() {
	$request_uri = $_SERVER['REQUEST_URI'];
	$request_uri = substr($request_uri, 0, strrpos($request_uri, '/')+1);
	return $request_uri;
}
function encodeURL($str) {
	if (!preg_match('/%[0-9A-F][0-9A-F]/', $str)) {
		$questionmarkposition = strrpos($str, '?');
		if ($questionmarkposition !== false) {
			$querystring = substr($str, $questionmarkposition);
			$str = substr($str, 0, $questionmarkposition);
		} else {
			$querystring = '';
		}
		$str = urlencode($str);
		$str = str_replace(array('http%3A%2F%2F', 'https%3A%2F%2F', '%2F'), array('http://', 'https://', '/'), $str);
		return $str.$querystring;
	} else {
		return $str;
	}
}
include('./data/settings/url.inc.php');
if (substr($urlbefore, 0 ,1) == '/') {
	$urlbefore = getServerName().encodeURL($urlbefore);
} elseif (substr($urlbefore, 0 ,4) != 'http') {
	$urlbefore = getServerName().encodeURL(getRequestUri()).encodeURL($urlbefore);
}
?>

==> cms-db_v0.9.tar.gz: admin/xmlurls.inc.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

if (!defined('cms-db')) {
	include('friendlyerror.firewall.inc.php');
	die();
}

function getServerName() {
	$server_name = 'http';
	if (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] == 'on') {
		$server_name .= 's';
	}
	$server_name .= '://';
	if ($_SERVER['SERVER_PORT'] != '80') {
		$server_name .= $_SERVER['SERVER_NAME'].':'.$_SERVER['SERVER_PORT'];
	} else {
		$server_name .= $_SERVER['SERVER_NAME'];
	}
	return $server_name;
}
function getRequestUri() {
	$request_uri = $_SERVER['REQUEST_URI'];
	$request_uri = substr($request_uri, 0, strrpos($request_uri, '/')+1);
	return $request_uri;
}
function encodeURL($str) {
	if (!preg_match('/%[0-9A-F][0-9A-F]/', $str)) {
		$questionmarkposition = strrpos($str, '?');
		if ($questionmarkposition !== false) {
			$querystring = substr($str, $questionmarkposition);
			$str = substr($str, 0, $questionmarkposition);
		} else {
			$querystring = '';
		}
		$str = urlencode($str);
		$str = str_replace(array('http%3A%2F%2F', 'https%3A%2F%2F', '%2F'), array('http://', 'https://', '/'), $str);
		return $str.$querystring;
	} else {
		return $str;
	}
}
include('./data/settings/url.inc.php');
if (substr($urlbefore, 0 ,1) == '/') {
	$urlbefore = getServerName().encodeURL($urlbefore);
} elseif (substr($urlbefore, 0 ,4) != 'http') {
	$urlbefore = getServerName().encodeURL(getRequestUri()).encodeURL($urlbefore);
}
?>
